use std::time::Duration;

use telers::{
    event::{telegram::HandlerResult, EventReturn},
    types::{Dice, Message},
    Bot,
};
use tokio::time::sleep;

use crate::{
    types::enums::{target_user::TargetUser, time_metrics::TimeDuration},
    utils::telegram::args_parser::Argument,
};

const DICE_DELAY_MS: u64 = 4000u64;
const CASINO_DELAY_MS: u64 = 1500u64;

pub async fn dice_handler(_bot: Bot, message: Message) -> HandlerResult {
    let (_chat_id, dice): (i64, Dice) = (message.chat().id(), message.dice().unwrap().clone());

    let (mute_time, emoji): (TimeDuration, &str) = (TimeDuration::Days(dice.value), &dice.emoji);

    let target_user = TargetUser::Reply(message.clone());
    let _args = [Argument::User(target_user), Argument::Time(mute_time)];

    match emoji {
        "🎲" => {
            sleep(Duration::from_millis(DICE_DELAY_MS)).await;
            todo!()
        }
        "🎰" => {
            if dice.value == 64 {
                sleep(Duration::from_millis(CASINO_DELAY_MS)).await;
                todo!()
            } else {
                sleep(Duration::from_millis(CASINO_DELAY_MS)).await;
                todo!()
            }
        }
        _ => (),
    }

    Ok(EventReturn::Finish)
}
