#[allow(dead_code)]
#[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord)]
pub enum TimeDuration {
    Minutes(i64),
    Hours(i64),
    Days(i64),
    Weeks(i64),
    Mounths(i64),
}

impl<'a> TimeDuration {
    pub fn from(metric: impl Into<&'a str>, duration: i64) -> Option<Self> {
        match metric.into() {
            "m" | "min" | "minutes" | "minute" | "минута" | "минуты" | "минут" | "мин" | "м" => {
                Some(Self::Minutes(duration))
            }
            "h" | "hours" | "hour" | "час" | "часов" | "ч" => Some(Self::Hours(duration)),
            "d" | "days" | "day" | "день" | "дня" | "дней" | "д" => {
                Some(Self::Days(duration))
            }
            "w" | "weeks" | "week" | "недель" | "недели" | "неделя" | "н" => {
                Some(Self::Weeks(duration))
            }
            "M" | "months" | "month" | "месяц" | "месяца" | "месяцев" | "мес" | "М" => {
                Some(Self::Mounths(duration))
            }
            _ => None,
        }
    }

    pub fn extract(self) -> i64 {
        match self {
            Self::Minutes(min) => min,
            Self::Hours(hrs) => hrs,
            Self::Days(day) => day,
            Self::Weeks(wks) => wks,
            Self::Mounths(mon) => mon,
        }
    }

    pub fn get_word_declensions(self) -> (impl Into<String>, impl Into<String>, impl Into<String>) {
        match self {
            Self::Minutes(_) => ("минута", "минуты", "минут"),
            Self::Hours(_) => ("час", "часов", "часов"),
            Self::Days(_) => ("день", "дня", "дней"),
            Self::Weeks(_) => ("неделя", "недели", "недель"),
            Self::Mounths(_) => ("месяц", "месяца", "месяцев"),
        }
    }
}
